[![Build Status](https://travis-ci.org/SpiNNakerManchester/sPyNNaker8.svg?branch=master)](https://travis-ci.org/SpiNNakerManchester/sPyNNaker8)
[![Coverage Status](https://coveralls.io/repos/github/SpiNNakerManchester/sPyNNaker8/badge.svg?branch=master)](https://coveralls.io/github/SpiNNakerManchester/sPyNNaker8?branch=master)

Tools for simulating neural models generated using PyNN 0.9 on the SpiNNaker platform

Documentation
=============
[sPyNNaker8 python documentation](http://spynnaker8.readthedocs.io/en/latest/)

[Combined python documentation](http://spinnaker8manchester.readthedocs.io)
